@@ -156,7 +156,7 @@ class Dict(dict):
                 continue
             
             if line.startswith(b'#'):	# skip comments but add to free list
-                if len(line) > 5:
+                if len(line) > 5 and offset > 0:
                     self._free_lines.append( (len(line), offset) )
             else:
                 # let's parse the value as well to be sure the data is ok
@@ -199,6 +199,16 @@ class Dict(dict):
         value = parseValue(line)
         return value
         
+       
+    def get(self, key, default=None):
+        try:
+            return self.__getitem__(key)
+        except KeyError:
+            return default
+        except:
+            raise
+            
+            
     def __setitem__(self, key, value):
         # trigger observers
         if self._observers:
@@ -277,8 +287,9 @@ class Dict(dict):
         return (key in self._offsets)
     
     def setdefault(self, key, val):
-        # See https://github.com/dagnelies/pysos/issues/3
-        raise UserWarning('Operation not available')
+        if key not in self:
+            self[key] = val
+        return self[key]
         
     def observe(self, callback):
         self._observers.append(callback)
@@ -348,6 +359,16 @@ class List(list):
         key = self._indexes[i]
         return self._dict[key]
         
+    
+    def get(self, key, default=None):
+        try:
+            return self.__getitem__(key)
+        except KeyError:
+            return default
+        except:
+            raise
+            
+            
     def __setitem__(self, i, value):
         # trigger observers
         if self._observers:
